aboutsummaryrefslogtreecommitdiff
path: root/src/testing/testing_api_cmd_auditor_add.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/testing/testing_api_cmd_auditor_add.c')
-rw-r--r--src/testing/testing_api_cmd_auditor_add.c8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/testing/testing_api_cmd_auditor_add.c b/src/testing/testing_api_cmd_auditor_add.c
index 8362b66c9..41182b7c7 100644
--- a/src/testing/testing_api_cmd_auditor_add.c
+++ b/src/testing/testing_api_cmd_auditor_add.c
@@ -62,13 +62,15 @@ struct AuditorAddState
* if the response code is acceptable.
*
* @param cls closure.
* @param hr HTTP response details
*/
static void
-auditor_add_cb (void *cls,
- const struct TALER_EXCHANGE_HttpResponse *hr)
+auditor_add_cb (
+ void *cls,
+ const struct TALER_EXCHANGE_ManagementAuditorEnableResponse *aer)
{
struct AuditorAddState *ds = cls;
+ const struct TALER_EXCHANGE_HttpResponse *hr = &aer->hr;
ds->dh = NULL;
if (ds->expected_response_code != hr->http_status)
@@ -62,13 +62,15 @@ struct AuditorAddState
*
* @param cls closure.
- * @param hr HTTP response details
+ * @param aer response details
*/
static void